DeviceService class

Service to handle Device management (tds) operations.

Inheritance

Constructors

DeviceService(OnvifClient client)

Properties

client OnvifClient
The client used to communicate with the ONVIF device.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getDeviceInformation() Future<Map<String, String>>
Retrieves the device information (Manufacturer, Model, Serial, etc.).
getSystemDateAndTime() Future<DateTime>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited