ImagingService class

Inheritance

Constructors

ImagingService(OnvifClient client)

Properties

client OnvifClient
The client used to communicate with the ONVIF device.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getIrCutFilter(String videoSourceToken) Future<OnvifIrCutFilter?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setIrCutFilter(String videoSourceToken, OnvifIrCutFilter mode) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited