OnvifNetworkInterface class

Constructors

OnvifNetworkInterface({required String token, required bool enabled, required bool dhcp, String? ipv4Address, int? prefixLength, String? hwAddress})
const

Properties

dhcp bool
true = currently using DHCP.
final
enabled bool
final
hashCode int
The hash code for this object.
no setterinherited
hwAddress String?
final
ipv4Address String?
Current IPv4 address (manual or from DHCP).
final
prefixLength int?
Subnet prefix length: 24 → 255.255.255.0, 16 → 255.255.0.0.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String
Interface token used in SetNetworkInterfaces (e.g. 'eth0', 'NetworkInterface_1').
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited